# JobsApi

All URIs are relative to *https://service.fax-api.de/4.0/rest*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getJobs**](JobsApi.md#getJobs) | **GET** /jobs | /jobs
[**postJob**](JobsApi.md#postJob) | **POST** /jobs | /jobs

<a name="getJobs"></a>
# **getJobs**
> Jobs getJobs(objectLimit, objectOffset, filterSameAccount, filterTitle, filterStatus, filterDateFrom, filterDateTo, filterDateUntilFrom, filterDateUntilTo, filterCostCenter, sortField, sortOrder)

/jobs

Description: Resource to obtain a list of fax jobs

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.JobsApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();

// Configure API key authorization: ApiAuthKey
ApiKeyAuth ApiAuthKey = (ApiKeyAuth) defaultClient.getAuthentication("ApiAuthKey");
ApiAuthKey.setApiKey("YOUR API KEY");
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//ApiAuthKey.setApiKeyPrefix("Token");

JobsApi apiInstance = new JobsApi();
Integer objectLimit = 100; // Integer | Query parameter to change de default limitation of objects in the result data array
Integer objectOffset = 0; // Integer | Query parameter to change de default offset of objects in the result data array
Boolean filterSameAccount = false; // Boolean | Query parameter to fetch jobs after the api account linked to the used token/key for authorization
String filterTitle = "filterTitle_example"; // String | Query parameter to fetch jobs after his title
String filterStatus = "filterStatus_example"; // String | Query parameter to fetch jobs after his status
OffsetDateTime filterDateFrom = new OffsetDateTime(); // OffsetDateTime | Query parameter to fetch jobs with a later date in TimeToSend. Can be combined with filterDateTo to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like '2022-01-01T10:00:00+01:00'. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00)
OffsetDateTime filterDateTo = new OffsetDateTime(); // OffsetDateTime | Query parameter to fetch jobs with a previous date in TimeToSend. Can be combined with filterDateFrom to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like '2022-01-01T10:00:00+02:00'. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00
OffsetDateTime filterDateUntilFrom = new OffsetDateTime(); // OffsetDateTime | Query parameter to fetch jobs with a later date in TimeToSendUntil. Can be combined with filterDateUntilTo to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like '2022-01-01T10:00:00+01:00'. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00)
OffsetDateTime filterDateUntilTo = new OffsetDateTime(); // OffsetDateTime | Query parameter to fetch jobs with a previous date in TimeToSendUntil. Can be combined with filterDateUIntilFrom to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like '2022-01-01T10:00:00+02:00'. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00
String filterCostCenter = "filterCostCenter_example"; // String | Query parameter to fetch jobs after his cost center
String sortField = "sortField_example"; // String | Available sort options for the result data array.
String sortOrder = "asc"; // String | Describes the order for used sort fields
try {
    Jobs result = apiInstance.getJobs(objectLimit, objectOffset, filterSameAccount, filterTitle, filterStatus, filterDateFrom, filterDateTo, filterDateUntilFrom, filterDateUntilTo, filterCostCenter, sortField, sortOrder);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling JobsApi#getJobs");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **objectLimit** | **Integer**| Query parameter to change de default limitation of objects in the result data array | [optional] [default to 100] [enum: ]
 **objectOffset** | **Integer**| Query parameter to change de default offset of objects in the result data array | [optional] [default to 0] [enum: ]
 **filterSameAccount** | **Boolean**| Query parameter to fetch jobs after the api account linked to the used token/key for authorization | [optional] [default to false]
 **filterTitle** | **String**| Query parameter to fetch jobs after his title | [optional]
 **filterStatus** | **String**| Query parameter to fetch jobs after his status | [optional] [enum: scheduling, scheduled, processing, halted, locked, canceled, finished, error]
 **filterDateFrom** | **OffsetDateTime**| Query parameter to fetch jobs with a later date in TimeToSend. Can be combined with filterDateTo to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like &#x27;2022-01-01T10:00:00+01:00&#x27;. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00) | [optional]
 **filterDateTo** | **OffsetDateTime**| Query parameter to fetch jobs with a previous date in TimeToSend. Can be combined with filterDateFrom to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like &#x27;2022-01-01T10:00:00+02:00&#x27;. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00 | [optional]
 **filterDateUntilFrom** | **OffsetDateTime**| Query parameter to fetch jobs with a later date in TimeToSendUntil. Can be combined with filterDateUntilTo to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like &#x27;2022-01-01T10:00:00+01:00&#x27;. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00) | [optional]
 **filterDateUntilTo** | **OffsetDateTime**| Query parameter to fetch jobs with a previous date in TimeToSendUntil. Can be combined with filterDateUIntilFrom to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like &#x27;2022-01-01T10:00:00+02:00&#x27;. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00 | [optional]
 **filterCostCenter** | **String**| Query parameter to fetch jobs after his cost center | [optional]
 **sortField** | **String**| Available sort options for the result data array. | [optional] [enum: jobId, title, createTime, timeToSend, timeToSendUntil]
 **sortOrder** | **String**| Describes the order for used sort fields | [optional] [default to asc] [enum: asc, desc]

### Return type

[**Jobs**](Jobs.md)

### Authorization

[ApiAuthKey](../README.md#ApiAuthKey)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="postJob"></a>
# **postJob**
> InlineResponse201 postJob(body)

/jobs

Description: Resource to create a new fax job

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.JobsApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();

// Configure API key authorization: ApiAuthKey
ApiKeyAuth ApiAuthKey = (ApiKeyAuth) defaultClient.getAuthentication("ApiAuthKey");
ApiAuthKey.setApiKey("YOUR API KEY");
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//ApiAuthKey.setApiKeyPrefix("Token");

JobsApi apiInstance = new JobsApi();
JobPost body = new JobPost(); // JobPost | Describes the required request body to create a new fax job
try {
    InlineResponse201 result = apiInstance.postJob(body);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling JobsApi#postJob");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**JobPost**](JobPost.md)| Describes the required request body to create a new fax job |

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

[ApiAuthKey](../README.md#ApiAuthKey)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

